                         ---------------------------------------------------------------------------------------------------------------------
                        | The enclosed FORTRAN code provide public access to the transient localization length (mobility) published in:       |                                         
                        |                                                                                                                     |
                        | "Practical Computation of the Charge Mobility in Molecular Semiconductors Using Transient Localization Theory"      |          
                        |  The Journal of Physical Chemistry C    https://pubs.acs.org/doi/10.1021/acs.jpcc.8b11916                           |
                        |                                                                                                                     |
                        |                                                                                                                     |
                        |  Code written by Tahereh Nematiaram (U. Liverpool), Alessandro Troisi (U.Liverpool), Sergio Ciuchi (U. L'Aquila).   |
                        |                                                                                                                     |
                        | > The primary reference for the theory of transient localization is:                                                |
                        | [1] Ciuchi, S., et al. "Transient localization in crystalline organic semiconductors."                              |
                        |     Physical Review B 83.8 (2011): 081202.                                                                          |
                        |                                                                                                                     |
                        | > Validation of transient localization theory against a set of experimental data is given in:                       |
                        | [2] Fratini, S., et al. "A map of high-mobility molecular semiconductors." Nature materials 16.10 (2017): 998.      |
                        |                                                                                                                     |
                        | > The numerical method used in this code with a summary of the theory is discussed in:                              |
                        | [3] Nematiaram, T., et al.,"Practical computation of the charge mobility in molecular semiconductors using transient|
                        |     localization theory", J. Phys. Chem. C (2019).    https://pubs.acs.org/doi/10.1021/acs.jpcc.8b11916             |
                        |                                                                                                                     |
                        | > A permanent link with different versions of this code that will be updated by Sergio Ciuchi is:                   |
                        |                                                                                                                     |
                        |                                 https://github.com/CiuK1469/TransLoc                                                |
                        |                                                                                                                     |
                         ---------------------------------------------------------------------------------------------------------------------





> List of files:

  gm.inp : this is the input file where the number of molecules in the unit cell, their position in the unit cell, 
           the unit cell vectors, the supercell size and the interacting molecules and their interaction type are
           specified.
           
  gm.f   : generates the morphology using the information in "gm.inp". This file doesn't need to be modified for 
           different input files.


  tll.f  : performs transient localization calculation on a cross section of the spherical map with the connectivity
           read from the output of gm.f
   
 

    
> How to compile the code:

 1- Prepare an input file "gm.inp"


 2- Compile gm.f:

    gfortran gm.f -o gm.x
    ./gm.x

    outputs:
    coordinates.dat  :  the xyz coordinate of each site (useful to extract mobility tensor)
    connectivity.dat :  the connectivity of the sparse Hamiltonian (interacting pairs and their type of interaction)
    pbc.dat          :  contains the Periodic Boundary Condition info for the supercell


 3- Compile tll.f 

    The code contains LAPACK library and should be launched by the following command
    (make sure that the lapack and blas libraies are installed):

    gfortran tll.f -o tll.x -llapack
    ./tll.x

    or 
    
    gfortran tll.f -o tll.x  -L. /usr/local/lib/liblapack.a  /usr/local/lib/libblas.a
    ./tll.x
 
    Output:
    unavgd_tll.dat    :   Unaveraged Squared Transient Localization Length
    avgd_tll.dat      :   Averaged Squared Transient Localization Length (figure 2 in the manuscript)
    cpu time          :   cpu time for the calculation



> How to visulaize the result:

    One can use different programs to viuslaize the results (e.g. MATLAB). The easiest way:

    gnuplot 
    plot 'avgd_tll.dat' w p


    gnuplot 
    plot 'unavgd_tll.dat' w p
 


> Note: As it is obvious, large supercell size(gm.inp) and high number of disorder realizations (nrp in tll.f) will demand longer computational time.





 
